@@ -9,7 +9,7 @@
 
 #pragma once
 
-#include <openrct2/common.h>
+#include <openrct2/localisation/StringIdType.h>
 
 namespace OpenRCT2
 {
@@ -258,7 +258,17 @@ namespace OpenRCT2
         STR_SHORTCUT_ZOOM_VIEW_IN = 2498,
         STR_SHORTCUT_ZOOM_VIEW_OUT = 2497,
 
+        // Widgets
+        STR_CLOSE_X = 824,
+        STR_CLOSE_X_WHITE = 6164,
+        STR_DROPDOWN_GLYPH = 876,
+        STR_NUMERIC_DOWN = 1219,
+        STR_NUMERIC_UP = 1218,
+        STR_TOGGLE_OPTION = 1156,
+        STR_TOGGLE_OPTION_CHECKED = 1157, // Used as STR_TOGGLE_OPTION + 1
+
         // Window: About.cpp
+        STR_ABOUT = 847,
         STR_ABOUT_FAIRGROUND_ORGAN = 6588,
         STR_ABOUT_OPENRCT2_DESCRIPTION = 6137,
         STR_ABOUT_OPENRCT2_DESCRIPTION_2 = 6138,
@@ -314,6 +324,7 @@ namespace OpenRCT2
         STR_TEXT_COLOUR_YELLOW = 3001,
 
         // Window: Changelog
+        STR_CHANGELOG_TITLE = 5344,
         STR_CONTRIBUTORS_WINDOW = 6542,
         STR_NEW_RELEASE_DOWNLOAD_PAGE = 6383,
         STR_NEW_RELEASE_VERSION_INFO = 6382,
@@ -482,6 +493,7 @@ namespace OpenRCT2
         STR_OBJECT_SELECTION = 3181,
         STR_OBJECT_SELECTION_ADVANCED = 3364,
         STR_OBJECT_SELECTION_ADVANCED_TIP = 3365,
+        STR_OBJECT_SELECTION_ALL_SOURCES_SHOWN = 6653,
         STR_OBJECT_SELECTION_COMPAT_OBJECT_DESCRIPTION = 6550,
         STR_OBJECT_SELECTION_FALLBACK_IMAGES_WARNING = 6516,
         STR_OBJECT_SELECTION_FOOTPATHS = 3189,
@@ -489,6 +501,7 @@ namespace OpenRCT2
         STR_OBJECT_SELECTION_FOOTPATH_SURFACES = 6444,
         STR_OBJECT_SELECTION_LARGE_SCENERY = 3186,
         STR_OBJECT_SELECTION_MUSIC = 6273,
+        STR_OBJECT_SELECTION_ONLY_STRINGID = 6655,
         STR_OBJECT_SELECTION_PATH_EXTRAS = 3190,
         STR_OBJECT_SELECTION_PATH_SIGNS = 3188,
         STR_OBJECT_SELECTION_RIDE_VEHICLES_ATTRACTIONS = 3184,
@@ -500,6 +513,7 @@ namespace OpenRCT2
         STR_OBJECT_SELECTION_TERRAIN_SURFACES = 6270,
         STR_OBJECT_SELECTION_WALLS_FENCES = 3187,
         STR_OBJECT_SELECTION_WATER = 3193,
+        STR_OBJECT_SELECTION_SHOWING_N_SOURCES = 6654,
         STR_OBJECT_USES_FALLBACK_IMAGES = 6515,
         STR_RELOAD_OBJECT_TIP = 6613,
         STR_RIDE_OBJECT_SHOP_SELLS = 6452,
@@ -1009,6 +1023,7 @@ namespace OpenRCT2
         STR_OBJECT_ERROR_WINDOW_FILE = 6127,
         STR_OBJECT_LOAD_ERROR_TITLE = 6123,
         STR_OBJECT_NAME = 6124,
+        STR_OBJECT_SELECTION_PARK_ENTRANCE = 3192,
         STR_OBJECT_SOURCE = 6131,
         STR_OBJECT_TYPE = 6125,
 
@@ -1325,6 +1340,8 @@ namespace OpenRCT2
         STR_ARG_6_STRINGID = 868,
         STR_ARRIVING_AT = 1103,
         STR_AVERAGE_SPEED = 1347,
+        STR_AUTHOR_STRING = 6646,
+        STR_AUTHORS_STRING = 6647,
         STR_BLOCK_SECTIONS = 3110,
         STR_BUILT_LAST_YEAR = 1854,
         STR_BUILT_THIS_YEAR = 1853,
@@ -1357,6 +1374,7 @@ namespace OpenRCT2
         STR_DIFFERENT_COLOURS_PER_VEHICLE = 1131,
         STR_DOING_CIRCUS_SHOW = 1117,
         STR_DOWN_TIME_LABEL_1889 = 1889,
+        STR_DROPDOWN_MENU_LABEL = 1142,
         STR_DROPDOWN_MENU_LABEL_SELECTED = 1143,
         STR_DROPS = 1355,
         STR_ENTER_NEW_NAME_FOR_THIS_RIDE_ATTRACTION = 1058,
@@ -1909,7 +1927,8 @@ namespace OpenRCT2
         STR_THEMES_WINDOW_EDITOR_INVENTION_LIST = 5211,
         STR_THEMES_WINDOW_EDITOR_OBJECT_SELECTION = 5210,
         STR_THEMES_WINDOW_EDITOR_SCENARIO_OPTIONS = 5212,
-        STR_THEMES_WINDOW_EDTIOR_OBJECTIVE_OPTIONS = 5213,
+        STR_THEMES_WINDOW_EDITOR_OBJECTIVE_OPTIONS = 5213,
+        STR_THEMES_WINDOW_ERROR = 6652,
         STR_THEMES_WINDOW_FINANCES = 5187,
         STR_THEMES_WINDOW_FIRE_PROMPT = 5225,
         STR_THEMES_WINDOW_FOOTPATH = 5198,
