@@ -24,6 +24,7 @@
 #include <openrct2/interface/Viewport.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/rct2/T6Exporter.h>
+#include <openrct2/ride/Ride.h>
 #include <openrct2/ride/RideConstruction.h>
 #include <openrct2/ride/Vehicle.h>
 #include <openrct2/ui/WindowManager.h>
@@ -129,6 +130,8 @@ public:
                 return TitleMenuOpen();
             case WindowClass::TitleOptions:
                 return TitleOptionsOpen();
+            case WindowClass::TitleVersion:
+                return TitleVersionOpen();
             case WindowClass::TopToolbar:
                 return TopToolbarOpen();
             case WindowClass::ViewClipping:
@@ -317,18 +320,7 @@ public:
                 // Check if window is already open
                 auto* window = WindowBringToFrontByClass(WindowClass::Scenery);
                 if (window == nullptr)
-                {
-                    auto* tlbrWindow = WindowFindByClass(WindowClass::TopToolbar);
-                    if (tlbrWindow != nullptr)
-                    {
-                        tlbrWindow->Invalidate();
-                        if (!ToolSet(*tlbrWindow, WC_TOP_TOOLBAR__WIDX_SCENERY, Tool::Arrow))
-                        {
-                            InputSetFlag(INPUT_FLAG_6, true);
-                            window = SceneryOpen();
-                        }
-                    }
-                }
+                    ToggleSceneryWindow();
 
                 // Switch to new scenery tab
                 WindowScenerySetSelectedTab(intent->GetUIntExtra(INTENT_EXTRA_SCENERY_GROUP_ENTRY_INDEX));
