@@ -15,9 +15,9 @@
 
 #include <SDL.h>
 #include <memory>
+#include <openrct2/Diagnostic.h>
 #include <openrct2/audio/AudioContext.h>
 #include <openrct2/audio/AudioSource.h>
-#include <openrct2/common.h>
 #include <openrct2/core/String.hpp>
 
 namespace OpenRCT2::Audio
