@@ -13,8 +13,8 @@
 
 #    include <SDL_video.h>
 #    include <algorithm>
+#    include <cassert>
 #    include <memory>
-#    include <openrct2/common.h>
 
 using namespace OpenRCT2::Ui;
 
