@@ -13,7 +13,7 @@
 
 #include <SDL_pixels.h>
 #include <array>
-#include <openrct2/common.h>
+#include <cassert>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/drawing/DrawingLock.hpp>
 #include <openrct2/sprites.h>
