@@ -8,7 +8,9 @@
  *****************************************************************************/
 
 #include "../UiStringIds.h"
+#include "../interface/ViewportInteraction.h"
 
+#include <cassert>
 #include <cmath>
 #include <iterator>
 #include <openrct2-ui/interface/Dropdown.h>
@@ -26,7 +28,6 @@
 #include <openrct2/interface/Cursors.h>
 #include <openrct2/interface/InteractiveConsole.h>
 #include <openrct2/localisation/Formatter.h>
-#include <openrct2/localisation/Localisation.h>
 #include <openrct2/platform/Platform.h>
 #include <openrct2/ride/RideData.h>
 #include <openrct2/scenario/Scenario.h>
@@ -36,6 +37,7 @@
 #include <optional>
 
 using namespace OpenRCT2;
+using namespace OpenRCT2::Ui;
 using namespace OpenRCT2::Ui::Windows;
 
 struct RCTMouseData
