@@ -39,12 +39,8 @@ static uint16_t toolSizeSpriteIndices[] =
 // clang-format on
 
 uint16_t gLandToolSize;
-money64 gLandToolRaiseCost;
-money64 gLandToolLowerCost;
 ObjectEntryIndex gLandToolTerrainSurface;
 ObjectEntryIndex gLandToolTerrainEdge;
-money64 gWaterToolRaiseCost;
-money64 gWaterToolLowerCost;
 
 uint32_t LandTool::SizeToSpriteIndex(uint16_t size)
 {
