@@ -13,7 +13,7 @@
 
 #    include "CustomImages.h"
 
-#    include <openrct2/drawing/Drawing.h>
+#    include <openrct2/drawing/Text.h>
 #    include <openrct2/scripting/Duktape.hpp>
 
 namespace OpenRCT2::Scripting
@@ -75,7 +75,7 @@ namespace OpenRCT2::Scripting
         void colour_set(DukValue value)
         {
             if (value.type() == DukValue::NUMBER)
-                _colour = static_cast<colour_t>(value.as_int());
+                _colour = static_cast<colour_t>(value.as_uint());
             else
                 _colour = {};
         }
@@ -88,7 +88,7 @@ namespace OpenRCT2::Scripting
         void secondaryColour_set(DukValue value)
         {
             if (value.type() == DukValue::NUMBER)
-                _secondaryColour = static_cast<colour_t>(value.as_int());
+                _secondaryColour = static_cast<colour_t>(value.as_uint());
             else
                 _secondaryColour = {};
         }
@@ -101,7 +101,7 @@ namespace OpenRCT2::Scripting
         void tertiaryColour_set(DukValue value)
         {
             if (value.type() == DukValue::NUMBER)
-                _tertiaryColour = static_cast<colour_t>(value.as_int());
+                _tertiaryColour = static_cast<colour_t>(value.as_uint());
             else
                 _tertiaryColour = {};
         }
@@ -114,7 +114,7 @@ namespace OpenRCT2::Scripting
         void paletteId_set(DukValue value)
         {
             if (value.type() == DukValue::NUMBER)
-                _paletteId = static_cast<uint8_t>(value.as_int());
+                _paletteId = static_cast<uint8_t>(value.as_uint());
             else
                 _paletteId = {};
         }
@@ -163,13 +163,13 @@ namespace OpenRCT2::Scripting
 
         void box(int32_t x, int32_t y, int32_t width, int32_t height)
         {
-            GfxFillRectInset(_dpi, { x, y, x + width - 1, y + height - 1 }, _colour.value_or(0), 0);
+            GfxFillRectInset(_dpi, { x, y, x + width - 1, y + height - 1 }, { _colour.value_or(0) }, 0);
         }
 
         void well(int32_t x, int32_t y, int32_t width, int32_t height)
         {
             GfxFillRectInset(
-                _dpi, { x, y, x + width - 1, y + height - 1 }, _colour.value_or(0),
+                _dpi, { x, y, x + width - 1, y + height - 1 }, { _colour.value_or(0) },
                 INSET_RECT_FLAG_BORDER_INSET | INSET_RECT_FLAG_FILL_DONT_LIGHTEN);
         }
 
@@ -235,7 +235,7 @@ namespace OpenRCT2::Scripting
 
         void text(const std::string& text, int32_t x, int32_t y)
         {
-            GfxDrawString(_dpi, { x, y }, text.c_str(), { _colour.value_or(0) });
+            DrawText(_dpi, { x, y }, { _colour.value_or(0) }, text.c_str());
         }
     };
 } // namespace OpenRCT2::Scripting
