@@ -11,20 +11,19 @@
 
 #include <openrct2-ui/interface/Window.h>
 #include <openrct2/Identifiers.h>
-#include <openrct2/common.h>
-#include <openrct2/ride/Ride.h>
-#include <openrct2/windows/TileInspectorGlobals.h>
 #include <string_view>
 
-// TODO: only for WINDOW_SHIM_RAW below; we can do better.
-#include "../UiStringIds.h"
-
+struct ObjectEntryDescriptor;
 struct Peep;
+struct Ride;
+struct RideSelection;
 struct TileElement;
-struct Vehicle;
 struct TrackDesign;
+struct Vehicle;
+
 enum class GuestListFilterType : int32_t;
 enum class ScatterToolDensity : uint8_t;
+
 using loadsave_callback = void (*)(int32_t result, const utf8* path);
 using scenarioselect_callback = void (*)(const utf8* path);
 
@@ -33,29 +32,35 @@ namespace OpenRCT2::Ui::Windows
     extern bool gWindowSceneryScatterEnabled;
     extern uint16_t gWindowSceneryScatterSize;
     extern ScatterToolDensity gWindowSceneryScatterDensity;
-    extern uint8_t gWindowSceneryPaintEnabled;
     extern uint8_t gWindowSceneryRotation;
-    extern colour_t gWindowSceneryPrimaryColour;
-    extern colour_t gWindowScenerySecondaryColour;
-    extern colour_t gWindowSceneryTertiaryColour;
     extern bool gWindowSceneryEyedropperEnabled;
 
     WindowBase* AboutOpen();
     void WindowCampaignRefreshRides();
     WindowBase* ChangelogOpen(int personality);
     WindowBase* CheatsOpen();
+
     WindowBase* ClearSceneryOpen();
+    void ToggleClearSceneryWindow();
+
     WindowBase* CustomCurrencyOpen();
     WindowBase* DebugPaintOpen();
     WindowBase* EditorInventionsListOpen();
     WindowBase* EditorMainOpen();
     WindowBase* EditorObjectiveOptionsOpen();
     WindowBase* EditorScenarioOptionsOpen();
+
     WindowBase* FootpathOpen();
     void WindowFootpathResetSelectedPath();
+    void ToggleFootpathWindow();
+
     WindowBase* GuestOpen(Peep* peep);
+
     WindowBase* LandOpen();
+    void ToggleLandWindow();
+
     WindowBase* LandRightsOpen();
+
     WindowBase* MainOpen();
     WindowBase* MapgenOpen();
     WindowBase* MultiplayerOpen();
@@ -76,8 +81,12 @@ namespace OpenRCT2::Ui::Windows
     WindowBase* TitleLogoOpen();
     WindowBase* TitleMenuOpen();
     WindowBase* TitleOptionsOpen();
+    WindowBase* TitleVersionOpen();
     WindowBase* ViewportOpen();
+
     WindowBase* WaterOpen();
+    void ToggleWaterWindow();
+
     WindowBase* ViewClippingOpen();
     WindowBase* TransparencyOpen();
     WindowBase* AssetPacksOpen();
@@ -203,6 +212,7 @@ namespace OpenRCT2::Ui::Windows
     void WindowSceneryInit();
     void WindowSceneryResetSelectedSceneryItems();
     const ScenerySelection WindowSceneryGetTabSelection();
+    void ToggleSceneryWindow();
 
     extern uint8_t gToolbarDirtyFlags;
     WindowBase* GameBottomToolbarOpen();
@@ -224,15 +234,4 @@ namespace OpenRCT2::Ui::Windows
     WindowBase* SceneryScatterOpen();
     WindowBase* PatrolAreaOpen(EntityId staffId);
     EntityId WindowPatrolAreaGetCurrentStaffId();
-
-    // clang-format off
-#define WINDOW_SHIM_RAW(TITLE, WIDTH, HEIGHT, CLOSE_STR) \
-    { WindowWidgetType::Frame,    0,  0,          WIDTH - 1, 0, HEIGHT - 1, 0xFFFFFFFF,  STR_NONE }, \
-    { WindowWidgetType::Caption,  0,  1,          WIDTH - 2, 1, 14,         TITLE,       STR_WINDOW_TITLE_TIP }, \
-    { WindowWidgetType::CloseBox, 0,  WIDTH - 13, WIDTH - 3, 2, 13,         CLOSE_STR, STR_CLOSE_WINDOW_TIP }
-
-#define WINDOW_SHIM(TITLE, WIDTH, HEIGHT) WINDOW_SHIM_RAW(TITLE, WIDTH, HEIGHT, STR_CLOSE_X)
-#define WINDOW_SHIM_WHITE(TITLE, WIDTH, HEIGHT) WINDOW_SHIM_RAW(TITLE, WIDTH, HEIGHT, STR_CLOSE_X_WHITE)
-
-    // clang-format on
 } // namespace OpenRCT2::Ui::Windows
