@@ -9,7 +9,6 @@
 
 #pragma once
 
-#include "common.h"
 #include "core/String.hpp"
 #include "object/Object.h"
 #include "object/ObjectList.h"
@@ -51,17 +50,18 @@ struct IParkImporter
 public:
     virtual ~IParkImporter() = default;
 
-    virtual ParkLoadResult Load(const u8string& path) abstract;
-    virtual ParkLoadResult LoadSavedGame(const u8string& path, bool skipObjectCheck = false) abstract;
-    virtual ParkLoadResult LoadScenario(const u8string& path, bool skipObjectCheck = false) abstract;
+    virtual ParkLoadResult Load(const u8string& path) = 0;
+    virtual ParkLoadResult LoadSavedGame(const u8string& path, bool skipObjectCheck = false) = 0;
+    virtual ParkLoadResult LoadScenario(const u8string& path, bool skipObjectCheck = false) = 0;
     virtual ParkLoadResult LoadFromStream(
-        OpenRCT2::IStream* stream, bool isScenario, bool skipObjectCheck = false, const u8string& path = {}) abstract;
+        OpenRCT2::IStream* stream, bool isScenario, bool skipObjectCheck = false, const u8string& path = {})
+        = 0;
 
-    virtual void Import(OpenRCT2::GameState_t& gameState) abstract;
-    virtual bool GetDetails(ScenarioIndexEntry* dst) abstract;
+    virtual void Import(OpenRCT2::GameState_t& gameState) = 0;
+    virtual bool GetDetails(ScenarioIndexEntry* dst) = 0;
 };
 
-namespace ParkImporter
+namespace OpenRCT2::ParkImporter
 {
     [[nodiscard]] std::unique_ptr<IParkImporter> Create(const std::string& hintPath);
     [[nodiscard]] std::unique_ptr<IParkImporter> CreateS4();
@@ -71,7 +71,7 @@ namespace ParkImporter
     bool ExtensionIsOpenRCT2ParkFile(std::string_view extension);
     bool ExtensionIsRCT1(std::string_view extension);
     bool ExtensionIsScenario(std::string_view extension);
-} // namespace ParkImporter
+} // namespace OpenRCT2::ParkImporter
 
 class ObjectLoadException : public std::exception
 {
