@@ -10,6 +10,7 @@
 #include "GameAction.h"
 
 #include "../Context.h"
+#include "../Diagnostic.h"
 #include "../GameState.h"
 #include "../ReplayManager.h"
 #include "../core/Guard.hpp"
@@ -17,7 +18,6 @@
 #include "../core/MemoryStream.h"
 #include "../entity/MoneyEffect.h"
 #include "../localisation/Formatter.h"
-#include "../localisation/Localisation.h"
 #include "../network/network.h"
 #include "../platform/Platform.h"
 #include "../profiling/Profiling.h"
@@ -34,7 +34,7 @@
 
 using namespace OpenRCT2;
 
-namespace GameActions
+namespace OpenRCT2::GameActions
 {
     struct QueuedGameAction
     {
@@ -467,7 +467,7 @@ namespace GameActions
     {
         return ExecuteInternal(action, false);
     }
-} // namespace GameActions
+} // namespace OpenRCT2::GameActions
 
 const char* GameAction::GetName() const
 {
