@@ -20,7 +20,7 @@
 #include <type_traits>
 #include <variant>
 
-namespace GameActions
+namespace OpenRCT2::GameActions
 {
     /**
      * Common error codes for game actions.
@@ -56,11 +56,11 @@ namespace GameActions
     public:
         using StringVariant = std::variant<std::string, StringId>;
 
-        GameActions::Status Error = GameActions::Status::Ok;
+        OpenRCT2::GameActions::Status Error = OpenRCT2::GameActions::Status::Ok;
         StringVariant ErrorTitle = STR_NONE;
         StringVariant ErrorMessage = STR_NONE;
         std::array<uint8_t, 32> ErrorMessageArgs{};
-        CoordsXYZ Position = { LOCATION_NULL, LOCATION_NULL, LOCATION_NULL };
+        CoordsXYZ Position = { kLocationNull, kLocationNull, kLocationNull };
         money64 Cost = 0;
         ExpenditureType Expenditure = ExpenditureType::Count;
 
@@ -74,7 +74,7 @@ namespace GameActions
 #endif
 
         Result() = default;
-        Result(GameActions::Status error, StringId title, StringId message, uint8_t* args = nullptr);
+        Result(OpenRCT2::GameActions::Status error, StringId title, StringId message, uint8_t* args = nullptr);
 
         std::string GetErrorTitle() const;
         std::string GetErrorMessage() const;
@@ -102,4 +102,4 @@ namespace GameActions
         }
     };
 
-} // namespace GameActions
+} // namespace OpenRCT2::GameActions
