@@ -27,10 +27,10 @@ public:
     uint16_t GetActionFlags() const override;
 
     void Serialise(DataSerialiser& stream) override;
-    GameActions::Result Query() const override;
-    GameActions::Result Execute() const override;
+    OpenRCT2::GameActions::Result Query() const override;
+    OpenRCT2::GameActions::Result Execute() const override;
 
 private:
-    GameActions::Result CreateResult() const;
+    OpenRCT2::GameActions::Result CreateResult() const;
     money64 CalculatePrice() const;
 };
