@@ -10,10 +10,10 @@
 #include "ParkSetNameAction.h"
 
 #include "../Context.h"
+#include "../Diagnostic.h"
 #include "../GameState.h"
 #include "../core/MemoryStream.h"
 #include "../drawing/Drawing.h"
-#include "../localisation/Localisation.h"
 #include "../management/Finance.h"
 #include "../network/network.h"
 #include "../ui/UiContext.h"
@@ -21,6 +21,8 @@
 #include "../windows/Intent.h"
 #include "../world/Park.h"
 
+using namespace OpenRCT2;
+
 ParkSetNameAction::ParkSetNameAction(const std::string& name)
     : _name(name)
 {
