@@ -10,10 +10,9 @@
 #include "RideSetPriceAction.h"
 
 #include "../Cheats.h"
-#include "../common.h"
+#include "../Diagnostic.h"
 #include "../core/MemoryStream.h"
 #include "../interface/Window.h"
-#include "../localisation/Localisation.h"
 #include "../localisation/StringIds.h"
 #include "../management/Finance.h"
 #include "../ride/Ride.h"
@@ -21,6 +20,8 @@
 #include "../ride/ShopItem.h"
 #include "../world/Park.h"
 
+using namespace OpenRCT2;
+
 RideSetPriceAction::RideSetPriceAction(RideId rideIndex, money64 price, bool primaryPrice)
     : _rideIndex(rideIndex)
     , _price(price)
