@@ -28,6 +28,6 @@ public:
 
     void Serialise(DataSerialiser& stream) override;
 
-    GameActions::Result Query() const override;
-    GameActions::Result Execute() const override;
+    OpenRCT2::GameActions::Result Query() const override;
+    OpenRCT2::GameActions::Result Execute() const override;
 };
