@@ -9,6 +9,7 @@
 
 #include "WaterSetHeightAction.h"
 
+#include "../Diagnostic.h"
 #include "../GameState.h"
 #include "../OpenRCT2.h"
 #include "../management/Finance.h"
@@ -46,7 +47,7 @@ GameActions::Result WaterSetHeightAction::Query() const
 {
     auto res = GameActions::Result();
     res.Expenditure = ExpenditureType::Landscaping;
-    res.Position = { _coords, _height * COORDS_Z_STEP };
+    res.Position = { _coords, _height * kCoordsZStep };
 
     if (!(gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) && !GetGameState().Cheats.SandboxMode
         && GetGameState().Park.Flags & PARK_FLAGS_FORBID_LANDSCAPE_CHANGES)
@@ -82,7 +83,7 @@ GameActions::Result WaterSetHeightAction::Query() const
     }
 
     int32_t zHigh = surfaceElement->GetBaseZ();
-    int32_t zLow = _height * COORDS_Z_STEP;
+    int32_t zLow = _height * kCoordsZStep;
     if (surfaceElement->GetWaterHeight() > 0)
     {
         zHigh = surfaceElement->GetWaterHeight();
@@ -113,7 +114,7 @@ GameActions::Result WaterSetHeightAction::Execute() const
 {
     auto res = GameActions::Result();
     res.Expenditure = ExpenditureType::Landscaping;
-    res.Position = { _coords, _height * COORDS_Z_STEP };
+    res.Position = { _coords, _height * kCoordsZStep };
 
     int32_t surfaceHeight = TileElementHeight(_coords);
     FootpathRemoveLitter({ _coords, surfaceHeight });
@@ -130,7 +131,7 @@ GameActions::Result WaterSetHeightAction::Execute() const
 
     if (_height > surfaceElement->BaseHeight)
     {
-        surfaceElement->SetWaterHeight(_height * COORDS_Z_STEP);
+        surfaceElement->SetWaterHeight(_height * kCoordsZStep);
     }
     else
     {
