@@ -9,12 +9,11 @@
 
 #pragma once
 
-#include "../common.h"
 #include "../core/String.hpp"
 
 #include <cstdarg>
 
-namespace Console
+namespace OpenRCT2::Console
 {
     void Write(char c);
     void Write(const utf8* str);
@@ -32,4 +31,4 @@ namespace Console
         void WriteLine(const utf8* format, ...);
         void WriteLine_VA(const utf8* format, va_list args);
     } // namespace Error
-} // namespace Console
+} // namespace OpenRCT2::Console
