@@ -7,8 +7,6 @@
  * OpenRCT2 is licensed under the GNU General Public License version 3.
  *****************************************************************************/
 
-#include "../common.h"
-
 #ifdef _WIN32
 #    include <windows.h>
 #endif
@@ -34,6 +32,8 @@
 #include <string>
 #include <vector>
 
+using namespace OpenRCT2;
+
 enum class DIRECTORY_CHILD_TYPE
 {
     DC_DIRECTORY,
@@ -149,7 +149,7 @@ public:
         return false;
     }
 
-    virtual void GetDirectoryChildren(std::vector<DirectoryChild>& children, const std::string& path) abstract;
+    virtual void GetDirectoryChildren(std::vector<DirectoryChild>& children, const std::string& path) = 0;
 
 private:
     void PushState(const std::string& directory)
