@@ -9,14 +9,13 @@
 
 #pragma once
 
-#include "../common.h"
 #include "../core/String.hpp"
 
 #include <memory>
 #include <string>
 #include <vector>
 
-namespace FileScanner
+namespace OpenRCT2::FileScanner
 {
     struct FileInfo
     {
@@ -24,18 +23,18 @@ namespace FileScanner
         uint64_t Size;
         uint64_t LastModified;
     };
-} // namespace FileScanner
+} // namespace OpenRCT2::FileScanner
 
 struct IFileScanner
 {
     virtual ~IFileScanner() = default;
 
-    virtual const FileScanner::FileInfo& GetFileInfo() const abstract;
-    virtual const u8string& GetPath() const abstract;
-    virtual u8string GetPathRelative() const abstract;
+    virtual const OpenRCT2::FileScanner::FileInfo& GetFileInfo() const = 0;
+    virtual const u8string& GetPath() const = 0;
+    virtual u8string GetPathRelative() const = 0;
 
-    virtual void Reset() abstract;
-    virtual bool Next() abstract;
+    virtual void Reset() = 0;
+    virtual bool Next() = 0;
 };
 
 struct QueryDirectoryResult
@@ -46,7 +45,7 @@ struct QueryDirectoryResult
     uint32_t PathChecksum;
 };
 
-namespace Path
+namespace OpenRCT2::Path
 {
     /**
      * Scans a directory and optionally sub directories for files that matches the
@@ -65,4 +64,4 @@ namespace Path
     void QueryDirectory(QueryDirectoryResult* result, const std::string& pattern);
 
     [[nodiscard]] std::vector<std::string> GetDirectories(const std::string& path);
-} // namespace Path
+} // namespace OpenRCT2::Path
