@@ -7,6 +7,9 @@
  * OpenRCT2 is licensed under the GNU General Public License version 3.
  *****************************************************************************/
 
+#include "../Diagnostic.h"
+
+#include <algorithm>
 #include <array>
 #include <cstdio>
 #include <stdexcept>
@@ -28,6 +31,8 @@
 #include "FileSystem.hpp"
 #include "FileWatcher.h"
 
+using namespace OpenRCT2;
+
 #if defined(__linux__)
 FileWatcher::FileDescriptor::~FileDescriptor()
 {
