@@ -9,6 +9,7 @@
 
 #ifdef __ANDROID__
 
+#    include "../Diagnostic.h"
 #    include "../platform/Platform.h"
 #    include "IStream.hpp"
 #    include "MemoryStream.h"
@@ -135,7 +136,7 @@ public:
     }
 };
 
-namespace Zip
+namespace OpenRCT2::Zip
 {
     std::unique_ptr<IZipArchive> Open(std::string_view path, ZIP_ACCESS access)
     {
@@ -154,7 +155,7 @@ namespace Zip
         }
         return result;
     }
-} // namespace Zip
+} // namespace OpenRCT2::Zip
 
 extern "C" {
 JNIEXPORT jlong JNICALL Java_io_openrct2_ZipArchive_allocBytes(JNIEnv* env, jclass, jbyteArray input, jint numBytes);
