@@ -10,10 +10,10 @@
 #include "Drawing.h"
 
 #include "../Context.h"
+#include "../Diagnostic.h"
 #include "../Game.h"
 #include "../GameState.h"
 #include "../OpenRCT2.h"
-#include "../common.h"
 #include "../config/Config.h"
 #include "../core/Guard.hpp"
 #include "../object/Object.h"
@@ -21,11 +21,11 @@
 #include "../object/WaterEntry.h"
 #include "../platform/Platform.h"
 #include "../sprites.h"
-#include "../util/Util.h"
 #include "../world/Climate.h"
 #include "../world/Location.hpp"
 #include "LightFX.h"
 
+#include <cassert>
 #include <cstring>
 
 using namespace OpenRCT2;
@@ -668,12 +668,12 @@ ImageCatalogue ImageId::GetCatalogue() const
 
 static auto GetMaskFunction()
 {
-    if (AVX2Available())
+    if (Platform::AVX2Available())
     {
         LOG_VERBOSE("registering AVX2 mask function");
         return MaskAvx2;
     }
-    else if (SSE41Available())
+    else if (Platform::SSE41Available())
     {
         LOG_VERBOSE("registering SSE4.1 mask function");
         return MaskSse4_1;
