@@ -7,7 +7,6 @@
  * OpenRCT2 is licensed under the GNU General Public License version 3.
  *****************************************************************************/
 
-#include "../common.h"
 #include "../core/Guard.hpp"
 #include "Drawing.h"
 
@@ -66,7 +65,7 @@ void MaskSse4_1(
     int32_t width, int32_t height, const uint8_t* RESTRICT maskSrc, const uint8_t* RESTRICT colourSrc, uint8_t* RESTRICT dst,
     int32_t maskWrap, int32_t colourWrap, int32_t dstWrap)
 {
-    Guard::Fail("SSE 4.1 function called on a CPU that doesn't support SSE 4.1");
+    OpenRCT2::Guard::Fail("SSE 4.1 function called on a CPU that doesn't support SSE 4.1");
 }
 
 #endif // __SSE4_1__
