@@ -10,8 +10,8 @@
 #pragma once
 
 #include "../Identifiers.h"
-#include "../common.h"
 #include "../entity/EntityBase.h"
+#include "../localisation/StringIdType.h"
 #include "../ride/RideTypes.h"
 #include "../ride/Station.h"
 #include "../util/Util.h"
@@ -24,13 +24,13 @@ constexpr uint8_t kPeepMinEnergy = 32;
 constexpr uint8_t kPeepMaxEnergy = 128;
 constexpr uint8_t kPeepMaxEnergyTarget = 255; // Oddly, this differs from max energy!
 
-constexpr auto PEEP_CLEARANCE_HEIGHT = 4 * COORDS_Z_STEP;
+constexpr auto PEEP_CLEARANCE_HEIGHT = 4 * kCoordsZStep;
 
 class Formatter;
 struct TileElement;
 struct PaintSession;
 
-namespace GameActions
+namespace OpenRCT2::GameActions
 {
     class Result;
 }
@@ -394,7 +394,7 @@ public: // Peep
     bool CanBePickedUp() const;
     void Pickup();
     void PickupAbort(int32_t old_x);
-    [[nodiscard]] GameActions::Result Place(const TileCoordsXYZ& location, bool apply);
+    [[nodiscard]] OpenRCT2::GameActions::Result Place(const TileCoordsXYZ& location, bool apply);
     void RemoveFromRide();
     void FormatActionTo(Formatter&) const;
     void FormatNameTo(Formatter&) const;
