@@ -12,11 +12,11 @@
 #include "../Context.h"
 #include "../audio/AudioMixer.h"
 #include "../audio/audio.h"
+#include "../core/UTF8.h"
 #include "../drawing/Drawing.h"
 #include "../drawing/Text.h"
 #include "../localisation/Formatter.h"
 #include "../localisation/Formatting.h"
-#include "../localisation/Localisation.h"
 #include "../network/network.h"
 #include "../platform/Platform.h"
 #include "../util/Util.h"
