@@ -10,7 +10,6 @@
 #pragma once
 
 #include "../Identifiers.h"
-#include "../common.h"
 #include "../drawing/ImageId.hpp"
 #include "../localisation/Formatter.h"
 #include "../ride/RideTypes.h"
@@ -38,11 +37,15 @@ struct WindowCloseModifier;
 
 enum class VisibilityCache : uint8_t;
 enum class CursorID : uint8_t;
-enum class RideConstructionState : uint8_t;
 enum class CloseWindowModifier : uint8_t;
 
 using rct_windownumber = uint16_t;
 
+namespace OpenRCT2
+{
+    enum class RideConstructionState : uint8_t;
+}
+
 struct WindowIdentifier
 {
     WindowClass classification;
@@ -58,7 +61,7 @@ struct WidgetIdentifier
 extern WindowCloseModifier gLastCloseModifier;
 
 using WidgetFlags = uint32_t;
-namespace WIDGET_FLAGS
+namespace OpenRCT2::WIDGET_FLAGS
 {
     const WidgetFlags TEXT_IS_STRING = 1 << 0;
     const WidgetFlags IS_PRESSED = 1 << 2;
@@ -66,7 +69,7 @@ namespace WIDGET_FLAGS
     const WidgetFlags TOOLTIP_IS_STRING = 1 << 4;
     const WidgetFlags IS_HIDDEN = 1 << 5;
     const WidgetFlags IS_HOLDABLE = 1 << 6;
-} // namespace WIDGET_FLAGS
+} // namespace OpenRCT2::WIDGET_FLAGS
 
 enum class WindowWidgetType : uint8_t;
 
@@ -139,7 +142,7 @@ struct Widget
 
     bool IsVisible() const
     {
-        return !(flags & WIDGET_FLAGS::IS_HIDDEN);
+        return !(flags & OpenRCT2::WIDGET_FLAGS::IS_HIDDEN);
     }
 };
 
@@ -256,7 +259,7 @@ enum WINDOW_FLAGS
     WF_SCROLLING_TO_LOCATION = (1 << 3),
     WF_TRANSPARENT = (1 << 4),
     WF_NO_BACKGROUND = (1 << 5), // Instead of half transparency, completely remove the window background
-    WF_DEAD = (1U << 6),         // Window is closed and will be deleted in the next update.
+    WF_DEAD = (1u << 6),         // Window is closed and will be deleted in the next update.
     WF_7 = (1 << 7),
     WF_RESIZABLE = (1 << 8),
     WF_NO_AUTO_CLOSE = (1 << 9), // Don't auto close this window if too many windows are open
@@ -339,12 +342,6 @@ enum WindowDetail
     static_assert(widx == wc##__##widx, "Global WIDX of " #widx " doesn't match actual value.")
 
 constexpr int32_t WC_MAIN_WINDOW__0 = 0;
-constexpr int32_t WC_TOP_TOOLBAR__WIDX_PAUSE = 0;
-constexpr int32_t WC_TOP_TOOLBAR__WIDX_LAND = 8;
-constexpr int32_t WC_TOP_TOOLBAR__WIDX_WATER = 9;
-constexpr int32_t WC_TOP_TOOLBAR__WIDX_SCENERY = 10;
-constexpr int32_t WC_TOP_TOOLBAR__WIDX_PATH = 11;
-constexpr int32_t WC_TOP_TOOLBAR__WIDX_CLEAR_SCENERY = 17;
 constexpr int32_t WC_RIDE_CONSTRUCTION__WIDX_CONSTRUCT = 25;
 constexpr int32_t WC_RIDE_CONSTRUCTION__WIDX_ENTRANCE = 30;
 constexpr int32_t WC_RIDE_CONSTRUCTION__WIDX_EXIT = 31;
@@ -352,6 +349,7 @@ constexpr int32_t WC_RIDE_CONSTRUCTION__WIDX_ROTATE = 32;
 constexpr int32_t WC_MAZE_CONSTRUCTION__WIDX_MAZE_DIRECTION_GROUPBOX = WC_RIDE_CONSTRUCTION__WIDX_CONSTRUCT;
 constexpr int32_t WC_MAZE_CONSTRUCTION__WIDX_MAZE_ENTRANCE = WC_RIDE_CONSTRUCTION__WIDX_ENTRANCE;
 constexpr int32_t WC_MAZE_CONSTRUCTION__WIDX_MAZE_EXIT = WC_RIDE_CONSTRUCTION__WIDX_EXIT;
+constexpr int32_t WC_SCENERY__WIDX_SCENERY_BACKGROUND = 0;
 constexpr int32_t WC_SCENERY__WIDX_SCENERY_TAB_1 = 15;
 constexpr int32_t WC_SCENERY__WIDX_SCENERY_ROTATE_OBJECTS_BUTTON = 5;
 constexpr int32_t WC_SCENERY__WIDX_SCENERY_EYEDROPPER_BUTTON = 10;
@@ -492,6 +490,8 @@ extern bool gDisableErrorWindowSound;
 std::list<std::shared_ptr<WindowBase>>::iterator WindowGetIterator(const WindowBase* w);
 void WindowVisitEach(std::function<void(WindowBase*)> func);
 
+void WindowSetFlagForAllViewports(uint32_t viewportFlag, bool enabled);
+
 void WindowDispatchUpdateAll();
 void WindowUpdateAllViewports();
 void WindowUpdateAll();
@@ -504,41 +504,6 @@ WindowBase* WindowBringToFrontByClass(WindowClass cls);
 WindowBase* WindowBringToFrontByClassWithFlags(WindowClass cls, uint16_t flags);
 WindowBase* WindowBringToFrontByNumber(WindowClass cls, rct_windownumber number);
 
-WindowBase* WindowCreate(
-    std::unique_ptr<WindowBase>&& w, WindowClass cls, ScreenCoordsXY pos, int32_t width, int32_t height, uint32_t flags);
-template<typename T, typename... TArgs, typename std::enable_if<std::is_base_of<WindowBase, T>::value>::type* = nullptr>
-T* WindowCreate(
-    WindowClass cls, const ScreenCoordsXY& pos = {}, int32_t width = 0, int32_t height = 0, uint32_t flags = 0, TArgs&&... args)
-{
-    return static_cast<T*>(WindowCreate(std::make_unique<T>(std::forward<TArgs>(args)...), cls, pos, width, height, flags));
-}
-template<typename T, typename... TArgs, typename std::enable_if<std::is_base_of<WindowBase, T>::value>::type* = nullptr>
-T* WindowCreate(WindowClass cls, int32_t width, int32_t height, uint32_t flags, TArgs&&... args)
-{
-    return static_cast<T*>(
-        WindowCreate(std::make_unique<T>(std::forward<TArgs>(args)...), cls, {}, width, height, flags | WF_AUTO_POSITION));
-}
-template<typename T, typename std::enable_if<std::is_base_of<WindowBase, T>::value>::type* = nullptr>
-T* WindowFocusOrCreate(WindowClass cls, const ScreenCoordsXY& pos, int32_t width, int32_t height, uint32_t flags = 0)
-{
-    auto* w = WindowBringToFrontByClass(cls);
-    if (w == nullptr)
-    {
-        w = WindowCreate<T>(cls, pos, width, height, flags);
-    }
-    return static_cast<T*>(w);
-}
-template<typename T, typename std::enable_if<std::is_base_of<WindowBase, T>::value>::type* = nullptr>
-T* WindowFocusOrCreate(WindowClass cls, int32_t width, int32_t height, uint32_t flags = 0)
-{
-    auto* w = WindowBringToFrontByClass(cls);
-    if (w == nullptr)
-    {
-        w = WindowCreate<T>(cls, width, height, flags);
-    }
-    return static_cast<T*>(w);
-}
-
 void WindowClose(WindowBase& window);
 void WindowFlushDead();
 void WindowCloseByClass(WindowClass cls);
@@ -561,8 +526,7 @@ void WindowInvalidateAll();
 void WidgetInvalidate(WindowBase& w, WidgetIndex widgetIndex);
 void WidgetInvalidateByClass(WindowClass cls, WidgetIndex widgetIndex);
 void WidgetInvalidateByNumber(WindowClass cls, rct_windownumber number, WidgetIndex widgetIndex);
-void WindowInitScrollWidgets(WindowBase& w);
-void WindowUpdateScrollWidgets(WindowBase& w);
+
 int32_t WindowGetScrollDataIndex(const WindowBase& w, WidgetIndex widget_index);
 
 void WindowPushOthersRight(WindowBase& w);
@@ -576,19 +540,9 @@ void WindowViewportGetMapCoordsByCursor(
 void WindowViewportCentreTileAroundCursor(WindowBase& w, int32_t map_x, int32_t map_y, int32_t offset_x, int32_t offset_y);
 void WindowCheckAllValidZoom();
 void WindowZoomSet(WindowBase& w, ZoomLevel zoomLevel, bool atCursor);
-void WindowZoomIn(WindowBase& w, bool atCursor);
-void WindowZoomOut(WindowBase& w, bool atCursor);
-void MainWindowZoom(bool zoomIn, bool atCursor);
 
 void WindowDrawAll(DrawPixelInfo& dpi, int32_t left, int32_t top, int32_t right, int32_t bottom);
 void WindowDraw(DrawPixelInfo& dpi, WindowBase& w, int32_t left, int32_t top, int32_t right, int32_t bottom);
-void WindowDrawWidgets(WindowBase& w, DrawPixelInfo& dpi);
-void WindowDrawViewport(DrawPixelInfo& dpi, WindowBase& w);
-
-void WindowSetPosition(WindowBase& w, const ScreenCoordsXY& screenCoords);
-void WindowMovePosition(WindowBase& w, const ScreenCoordsXY& screenCoords);
-void WindowResize(WindowBase& w, int32_t dw, int32_t dh);
-void WindowSetResize(WindowBase& w, int32_t minWidth, int32_t minHeight, int32_t maxWidth, int32_t maxHeight);
 
 bool ToolSet(const WindowBase& w, WidgetIndex widgetIndex, Tool tool);
 void ToolCancel();
@@ -600,16 +554,11 @@ void WindowUpdateViewportRideMusic();
 Viewport* WindowGetViewport(WindowBase* window);
 
 // Open window functions
-void WindowRelocateWindows(int32_t width, int32_t height);
 void WindowResizeGui(int32_t width, int32_t height);
 void WindowResizeGuiScenarioEditor(int32_t width, int32_t height);
 
-void InvalidateAllWindowsAfterInput();
 void TextinputCancel();
 
-void WindowMoveAndSnap(WindowBase& w, ScreenCoordsXY newWindowCoords, int32_t snapProximity);
-int32_t WindowCanResize(const WindowBase& w);
-
 bool WindowIsVisible(WindowBase& w);
 
 bool SceneryToolIsActive();
@@ -628,4 +577,4 @@ money64 PlaceProvisionalTrackPiece(
     RideId rideIndex, int32_t trackType, int32_t trackDirection, int32_t liftHillAndAlternativeState,
     const CoordsXYZ& trackPos);
 
-extern RideConstructionState _rideConstructionState2;
+extern OpenRCT2::RideConstructionState _rideConstructionState2;
