@@ -16,8 +16,7 @@
 #include "../entity/Peep.h"
 #include "../entity/Staff.h"
 #include "../interface/Window.h"
-#include "../localisation/Date.h"
-#include "../localisation/Localisation.h"
+#include "../localisation/Localisation.Date.h"
 #include "../profiling/Profiling.h"
 #include "../ride/Ride.h"
 #include "../scenario/Scenario.h"
