@@ -9,7 +9,9 @@
 
 #include "Research.h"
 
+#include "../Context.h"
 #include "../Date.h"
+#include "../Diagnostic.h"
 #include "../Game.h"
 #include "../GameState.h"
 #include "../OpenRCT2.h"
@@ -19,9 +21,8 @@
 #include "../core/Guard.hpp"
 #include "../core/Memory.hpp"
 #include "../interface/Window.h"
-#include "../localisation/Date.h"
 #include "../localisation/Formatter.h"
-#include "../localisation/Localisation.h"
+#include "../localisation/Localisation.Date.h"
 #include "../localisation/StringIds.h"
 #include "../object/ObjectEntryManager.h"
 #include "../object/ObjectList.h"
@@ -34,6 +35,7 @@
 #include "../ride/TrackData.h"
 #include "../scenario/Scenario.h"
 #include "../util/Util.h"
+#include "../windows/Intent.h"
 #include "../world/Park.h"
 #include "../world/Scenery.h"
 #include "Finance.h"
@@ -56,6 +58,15 @@ static bool _researchedSceneryItems[SCENERY_TYPE_COUNT][UINT16_MAX];
 
 bool gSilentResearch = false;
 
+// clang-format off
+const StringId kResearchFundingLevelNames[] = {
+    STR_RESEARCH_FUNDING_NONE,
+    STR_RESEARCH_FUNDING_MINIMUM,
+    STR_RESEARCH_FUNDING_NORMAL,
+    STR_RESEARCH_FUNDING_MAXIMUM,
+};
+// clang-format on
+
 /**
  *
  *  rct2: 0x006671AD, part of 0x00667132
@@ -287,7 +298,9 @@ void ResearchFinishItem(const ResearchItem& researchItem)
             }
 
             ResearchInvalidateRelatedWindows();
-            SceneryInit();
+
+            auto intent = Intent(INTENT_ACTION_INIT_SCENERY);
+            ContextBroadcastIntent(&intent);
         }
     }
 }
