@@ -11,6 +11,7 @@
 
 #    include "NetworkServerAdvertiser.h"
 
+#    include "../Diagnostic.h"
 #    include "../GameState.h"
 #    include "../config/Config.h"
 #    include "../core/Console.hpp"
@@ -19,7 +20,7 @@
 #    include "../core/Json.hpp"
 #    include "../core/String.hpp"
 #    include "../entity/Guest.h"
-#    include "../localisation/Date.h"
+#    include "../localisation/Localisation.Date.h"
 #    include "../management/Finance.h"
 #    include "../platform/Platform.h"
 #    include "../util/Util.h"
@@ -344,7 +345,7 @@ private:
 
     static std::string GetMasterServerUrl()
     {
-        std::string result = OPENRCT2_MASTER_SERVER_URL;
+        std::string result = kMasterServerURL;
         if (!Config::Get().network.MasterServerUrl.empty())
         {
             result = Config::Get().network.MasterServerUrl;
