@@ -12,6 +12,7 @@
 #    include "ServerList.h"
 
 #    include "../Context.h"
+#    include "../Diagnostic.h"
 #    include "../PlatformEnvironment.h"
 #    include "../config/Config.h"
 #    include "../core/File.h"
@@ -359,7 +360,7 @@ std::future<std::vector<ServerListEntry>> ServerList::FetchOnlineServerListAsync
     auto p = std::make_shared<std::promise<std::vector<ServerListEntry>>>();
     auto f = p->get_future();
 
-    std::string masterServerUrl = OPENRCT2_MASTER_SERVER_URL;
+    std::string masterServerUrl = kMasterServerURL;
     if (!Config::Get().network.MasterServerUrl.empty())
     {
         masterServerUrl = Config::Get().network.MasterServerUrl;
