@@ -9,8 +9,8 @@
 
 #pragma once
 
-#include "../common.h"
 #include "../core/Money.hpp"
+#include "../localisation/StringIdType.h"
 #include "ObjectTypes.h"
 
 enum
