@@ -9,7 +9,7 @@
 
 #pragma once
 
-#include "../common.h"
+#include "../localisation/StringIdType.h"
 #include "ObjectTypes.h"
 
 struct EntranceEntry
