@@ -9,7 +9,6 @@
 
 #pragma once
 
-#include "../common.h"
 #include "../core/JsonFwd.hpp"
 #include "../core/String.hpp"
 #include "../util/Util.h"
@@ -30,7 +29,7 @@ constexpr size_t VersionNumFields = 3;
 using ObjectVersion = std::tuple<uint16_t, uint16_t, uint16_t>;
 static_assert(std::tuple_size<ObjectVersion>{} == VersionNumFields);
 
-namespace ObjectSelectionFlags
+namespace OpenRCT2::ObjectSelectionFlags
 {
     constexpr uint8_t Selected = (1 << 0);
     constexpr uint8_t InUse = (1 << 2);
@@ -38,7 +37,7 @@ namespace ObjectSelectionFlags
     constexpr uint8_t AlwaysRequired = (1 << 4);
     constexpr uint8_t Flag6 = (1 << 5);
     constexpr uint8_t AllFlags = 0xFF;
-}; // namespace ObjectSelectionFlags
+}; // namespace OpenRCT2::ObjectSelectionFlags
 
 enum class ObjectSourceGame : uint8_t
 {
@@ -101,7 +100,7 @@ struct RCTObjectEntry
     bool operator==(const RCTObjectEntry& rhs) const;
     bool operator!=(const RCTObjectEntry& rhs) const;
 };
-assert_struct_size(RCTObjectEntry, 0x10);
+static_assert(sizeof(RCTObjectEntry) == 0x10);
 
 #pragma pack(pop)
 
@@ -168,15 +167,15 @@ struct IReadObjectContext
 {
     virtual ~IReadObjectContext() = default;
 
-    virtual std::string_view GetObjectIdentifier() abstract;
-    virtual IObjectRepository& GetObjectRepository() abstract;
-    virtual bool ShouldLoadImages() abstract;
-    virtual std::vector<uint8_t> GetData(std::string_view path) abstract;
-    virtual ObjectAsset GetAsset(std::string_view path) abstract;
+    virtual std::string_view GetObjectIdentifier() = 0;
+    virtual IObjectRepository& GetObjectRepository() = 0;
+    virtual bool ShouldLoadImages() = 0;
+    virtual std::vector<uint8_t> GetData(std::string_view path) = 0;
+    virtual ObjectAsset GetAsset(std::string_view path) = 0;
 
-    virtual void LogVerbose(ObjectError code, const utf8* text) abstract;
-    virtual void LogWarning(ObjectError code, const utf8* text) abstract;
-    virtual void LogError(ObjectError code, const utf8* text) abstract;
+    virtual void LogVerbose(ObjectError code, const utf8* text) = 0;
+    virtual void LogWarning(ObjectError code, const utf8* text) = 0;
+    virtual void LogError(ObjectError code, const utf8* text) = 0;
 };
 
 #ifdef __WARN_SUGGEST_FINAL_TYPES__
@@ -285,8 +284,8 @@ public:
     {
     }
     virtual void ReadLegacy(IReadObjectContext* context, OpenRCT2::IStream* stream);
-    virtual void Load() abstract;
-    virtual void Unload() abstract;
+    virtual void Load() = 0;
+    virtual void Unload() = 0;
 
     virtual void DrawPreview(DrawPixelInfo& /*dpi*/, int32_t /*width*/, int32_t /*height*/) const
     {
