@@ -9,10 +9,10 @@
 
 #pragma once
 
-#include "../common.h"
+#include <cstdint>
 
-namespace PaintSessionFlags
+namespace OpenRCT2::PaintSessionFlags
 {
     constexpr uint8_t PassedSurface = 1u << 0;
     constexpr uint8_t IsTrackPiecePreview = 1u << 1;
-} // namespace PaintSessionFlags
+} // namespace OpenRCT2::PaintSessionFlags
