@@ -10,6 +10,7 @@
 #include "VirtualFloor.h"
 
 #include "../Cheats.h"
+#include "../Diagnostic.h"
 #include "../GameState.h"
 #include "../Input.h"
 #include "../config/Config.h"
@@ -300,10 +301,10 @@ void VirtualFloorPaint(PaintSession& session)
     PROFILED_FUNCTION();
 
     static constexpr CoordsXY scenery_half_tile_offsets[4] = {
-        { -COORDS_XY_STEP, 0 },
-        { 0, COORDS_XY_STEP },
-        { COORDS_XY_STEP, 0 },
-        { 0, -COORDS_XY_STEP },
+        { -kCoordsXYStep, 0 },
+        { 0, kCoordsXYStep },
+        { kCoordsXYStep, 0 },
+        { 0, -kCoordsXYStep },
     };
 
     if (_virtualFloorHeight < kMinimumLandHeight)
