@@ -14,10 +14,9 @@
 #include "../../config/Config.h"
 #include "../../core/Numerics.hpp"
 #include "../../core/String.hpp"
+#include "../../core/UTF8.h"
 #include "../../interface/Viewport.h"
-#include "../../localisation/Formatter.h"
 #include "../../localisation/Formatting.h"
-#include "../../localisation/Localisation.h"
 #include "../../localisation/StringIds.h"
 #include "../../object/LargeSceneryObject.h"
 #include "../../profiling/Profiling.h"
