@@ -12,6 +12,7 @@
 #    include "Platform.h"
 
 #    include "../Date.h"
+#    include "../Diagnostic.h"
 #    include "../core/Memory.hpp"
 #    include "../core/Path.hpp"
 #    include "../util/Util.h"
@@ -33,7 +34,7 @@
 // The name of the mutex used to prevent multiple instances of the game from running
 static constexpr const utf8* SINGLE_INSTANCE_MUTEX_NAME = u8"openrct2.lock";
 
-namespace Platform
+namespace OpenRCT2::Platform
 {
     std::string GetEnvironmentVariable(std::string_view name)
     {
@@ -368,6 +369,6 @@ namespace Platform
         datetime64 utcNow = epochAsTicks + utcEpochTicks;
         return utcNow;
     }
-} // namespace Platform
+} // namespace OpenRCT2::Platform
 
 #endif
