@@ -13,6 +13,9 @@
 #    ifndef WIN32_LEAN_AND_MEAN
 #        define WIN32_LEAN_AND_MEAN
 #    endif
+#    include "../Diagnostic.h"
+
+#    include <cassert>
 #    include <windows.h>
 
 // Then the rest
@@ -26,11 +29,10 @@
 
 #    include "../Date.h"
 #    include "../OpenRCT2.h"
-#    include "../common.h"
 #    include "../core/Path.hpp"
 #    include "../core/String.hpp"
-#    include "../localisation/Date.h"
 #    include "../localisation/Language.h"
+#    include "../localisation/Localisation.Date.h"
 #    include "Platform.h"
 
 #    include <cstring>
@@ -50,7 +52,7 @@ static constexpr wchar_t SINGLE_INSTANCE_MUTEX_NAME[] = L"RollerCoaster Tycoon 2
 #    define SOFTWARE_CLASSES L"Software\\Classes"
 #    define MUI_CACHE L"Local Settings\\Software\\Microsoft\\Windows\\Shell\\MuiCache"
 
-namespace Platform
+namespace OpenRCT2::Platform
 {
     static std::string WIN32_GetKnownFolderPath(REFKNOWNFOLDERID rfid);
     static std::string WIN32_GetModuleFileNameW(HMODULE hModule);
@@ -886,6 +888,6 @@ namespace Platform
         return false;
     }
 
-} // namespace Platform
+} // namespace OpenRCT2::Platform
 
 #endif
