@@ -9,8 +9,8 @@
 
 #pragma once
 
-#include "../common.h"
 #include "../config/ConfigTypes.h"
+#include "../core/DateTime.h"
 #include "../core/String.hpp"
 
 #include <ctime>
@@ -45,7 +45,7 @@ struct RealWorldDate;
 struct RealWorldTime;
 struct TTFFontDescriptor;
 
-namespace Platform
+namespace OpenRCT2::Platform
 {
     std::string GetEnvironmentVariable(std::string_view name);
     std::string GetFolderPath(SPECIAL_FOLDER folder);
@@ -124,7 +124,10 @@ namespace Platform
     uint32_t GetTicks();
 
     void Sleep(uint32_t ms);
-} // namespace Platform
+
+    bool SSE41Available();
+    bool AVX2Available();
+} // namespace OpenRCT2::Platform
 
 #ifdef __ANDROID__
 class AndroidClassLoader
