@@ -21,7 +21,11 @@
 #include "../ride/TrackDesign.h"
 #include "../ride/TrackDesignRepository.h"
 
-namespace RCT1
+#include <cassert>
+
+using namespace OpenRCT2;
+
+namespace OpenRCT2::RCT1
 {
     /**
      * Class to import RollerCoaster Tycoon 1 track designs (*.TD4).
@@ -262,7 +266,7 @@ namespace RCT1
             return td;
         }
     };
-} // namespace RCT1
+} // namespace OpenRCT2::RCT1
 
 std::unique_ptr<ITrackImporter> TrackImporter::CreateTD4()
 {
