@@ -10,9 +10,9 @@
 #include "T6Exporter.h"
 
 #include "../Context.h"
+#include "../Diagnostic.h"
 #include "../core/FileStream.h"
 #include "../core/MemoryStream.h"
-#include "../localisation/Localisation.h"
 #include "../localisation/StringIds.h"
 #include "../object/ObjectList.h"
 #include "../rct12/SawyerChunkWriter.h"
@@ -28,7 +28,7 @@
 
 #include <functional>
 
-namespace RCT2
+namespace OpenRCT2::RCT2
 {
     T6Exporter::T6Exporter(const TrackDesign& trackDesign)
         : _trackDesign(trackDesign)
@@ -189,4 +189,4 @@ namespace RCT2
         sawyerCoding.WriteChunkTrack(tempStream.GetData(), tempStream.GetLength());
         return true;
     }
-} // namespace RCT2
+} // namespace OpenRCT2::RCT2
