@@ -20,105 +20,105 @@
 #include "RideData.h"
 
 #include "../Cheats.h"
+#include "../Diagnostic.h"
 #include "../GameState.h"
 #include "../audio/audio.h"
 #include "../interface/Colour.h"
-#include "../localisation/Localisation.h"
 #include "../management/Research.h"
 #include "../sprites.h"
 #include "Ride.h"
 #include "ShopItem.h"
 #include "Track.h"
 #include "Vehicle.h"
-#include "coaster/meta/AirPoweredVerticalCoaster.h"
-#include "coaster/meta/AlpineCoaster.h"
-#include "coaster/meta/BobsleighCoaster.h"
-#include "coaster/meta/ClassicMiniRollerCoaster.h"
-#include "coaster/meta/ClassicStandUpRollerCoaster.h"
-#include "coaster/meta/ClassicWoodenRollerCoaster.h"
-#include "coaster/meta/CompactInvertedCoaster.h"
-#include "coaster/meta/CorkscrewRollerCoaster.h"
-#include "coaster/meta/FlyingRollerCoaster.h"
-#include "coaster/meta/GigaCoaster.h"
-#include "coaster/meta/HeartlineTwisterCoaster.h"
-#include "coaster/meta/HybridCoaster.h"
-#include "coaster/meta/HyperTwister.h"
-#include "coaster/meta/Hypercoaster.h"
-#include "coaster/meta/InvertedHairpinCoaster.h"
-#include "coaster/meta/InvertedImpulseCoaster.h"
-#include "coaster/meta/InvertedRollerCoaster.h"
-#include "coaster/meta/JuniorRollerCoaster.h"
-#include "coaster/meta/LIMLaunchedRollerCoaster.h"
-#include "coaster/meta/LayDownRollerCoaster.h"
-#include "coaster/meta/LoopingRollerCoaster.h"
-#include "coaster/meta/MineRide.h"
-#include "coaster/meta/MineTrainCoaster.h"
-#include "coaster/meta/MiniRollerCoaster.h"
-#include "coaster/meta/MiniSuspendedCoaster.h"
-#include "coaster/meta/MultiDimensionRollerCoaster.h"
-#include "coaster/meta/ReverseFreefallCoaster.h"
-#include "coaster/meta/ReverserRollerCoaster.h"
-#include "coaster/meta/SideFrictionRollerCoaster.h"
-#include "coaster/meta/SingleRailRollerCoaster.h"
-#include "coaster/meta/SpinningWildMouse.h"
-#include "coaster/meta/SpiralRollerCoaster.h"
-#include "coaster/meta/StandUpRollerCoaster.h"
-#include "coaster/meta/SteelWildMouse.h"
-#include "coaster/meta/Steeplechase.h"
-#include "coaster/meta/SuspendedSwingingCoaster.h"
-#include "coaster/meta/TwisterRollerCoaster.h"
-#include "coaster/meta/VerticalDropCoaster.h"
-#include "coaster/meta/VirginiaReel.h"
-#include "coaster/meta/WaterCoaster.h"
-#include "coaster/meta/WoodenRollerCoaster.h"
-#include "coaster/meta/WoodenWildMouse.h"
-#include "gentle/meta/CarRide.h"
-#include "gentle/meta/Circus.h"
-#include "gentle/meta/CrookedHouse.h"
-#include "gentle/meta/Dodgems.h"
-#include "gentle/meta/FerrisWheel.h"
-#include "gentle/meta/FlyingSaucers.h"
-#include "gentle/meta/GhostTrain.h"
-#include "gentle/meta/HauntedHouse.h"
-#include "gentle/meta/Maze.h"
-#include "gentle/meta/MerryGoRound.h"
-#include "gentle/meta/MiniGolf.h"
-#include "gentle/meta/MiniHelicopters.h"
-#include "gentle/meta/MonorailCycles.h"
-#include "gentle/meta/MonsterTrucks.h"
-#include "gentle/meta/ObservationTower.h"
-#include "gentle/meta/SpaceRings.h"
-#include "gentle/meta/SpiralSlide.h"
-#include "shops/meta/CashMachine.h"
-#include "shops/meta/DrinkStall.h"
-#include "shops/meta/FirstAid.h"
-#include "shops/meta/FoodStall.h"
-#include "shops/meta/InformationKiosk.h"
-#include "shops/meta/Shop.h"
-#include "shops/meta/Toilets.h"
-#include "thrill/meta/3DCinema.h"
-#include "thrill/meta/Enterprise.h"
-#include "thrill/meta/GoKarts.h"
-#include "thrill/meta/LaunchedFreefall.h"
-#include "thrill/meta/MagicCarpet.h"
-#include "thrill/meta/MotionSimulator.h"
-#include "thrill/meta/RotoDrop.h"
-#include "thrill/meta/SwingingInverterShip.h"
-#include "thrill/meta/SwingingShip.h"
-#include "thrill/meta/TopSpin.h"
-#include "thrill/meta/Twist.h"
-#include "transport/meta/Chairlift.h"
-#include "transport/meta/Lift.h"
-#include "transport/meta/MiniatureRailway.h"
-#include "transport/meta/Monorail.h"
-#include "transport/meta/SuspendedMonorail.h"
-#include "water/meta/BoatHire.h"
-#include "water/meta/DinghySlide.h"
-#include "water/meta/LogFlume.h"
-#include "water/meta/RiverRafts.h"
-#include "water/meta/RiverRapids.h"
-#include "water/meta/SplashBoats.h"
-#include "water/meta/SubmarineRide.h"
+#include "rtd/coaster/AirPoweredVerticalCoaster.h"
+#include "rtd/coaster/AlpineCoaster.h"
+#include "rtd/coaster/BobsleighCoaster.h"
+#include "rtd/coaster/ClassicMiniRollerCoaster.h"
+#include "rtd/coaster/ClassicStandUpRollerCoaster.h"
+#include "rtd/coaster/ClassicWoodenRollerCoaster.h"
+#include "rtd/coaster/CompactInvertedCoaster.h"
+#include "rtd/coaster/CorkscrewRollerCoaster.h"
+#include "rtd/coaster/FlyingRollerCoaster.h"
+#include "rtd/coaster/GigaCoaster.h"
+#include "rtd/coaster/HeartlineTwisterCoaster.h"
+#include "rtd/coaster/HybridCoaster.h"
+#include "rtd/coaster/HyperTwister.h"
+#include "rtd/coaster/Hypercoaster.h"
+#include "rtd/coaster/InvertedHairpinCoaster.h"
+#include "rtd/coaster/InvertedImpulseCoaster.h"
+#include "rtd/coaster/InvertedRollerCoaster.h"
+#include "rtd/coaster/JuniorRollerCoaster.h"
+#include "rtd/coaster/LIMLaunchedRollerCoaster.h"
+#include "rtd/coaster/LayDownRollerCoaster.h"
+#include "rtd/coaster/LoopingRollerCoaster.h"
+#include "rtd/coaster/MineRide.h"
+#include "rtd/coaster/MineTrainCoaster.h"
+#include "rtd/coaster/MiniRollerCoaster.h"
+#include "rtd/coaster/MiniSuspendedCoaster.h"
+#include "rtd/coaster/MultiDimensionRollerCoaster.h"
+#include "rtd/coaster/ReverseFreefallCoaster.h"
+#include "rtd/coaster/ReverserRollerCoaster.h"
+#include "rtd/coaster/SideFrictionRollerCoaster.h"
+#include "rtd/coaster/SingleRailRollerCoaster.h"
+#include "rtd/coaster/SpinningWildMouse.h"
+#include "rtd/coaster/SpiralRollerCoaster.h"
+#include "rtd/coaster/StandUpRollerCoaster.h"
+#include "rtd/coaster/SteelWildMouse.h"
+#include "rtd/coaster/Steeplechase.h"
+#include "rtd/coaster/SuspendedSwingingCoaster.h"
+#include "rtd/coaster/TwisterRollerCoaster.h"
+#include "rtd/coaster/VerticalDropCoaster.h"
+#include "rtd/coaster/VirginiaReel.h"
+#include "rtd/coaster/WaterCoaster.h"
+#include "rtd/coaster/WoodenRollerCoaster.h"
+#include "rtd/coaster/WoodenWildMouse.h"
+#include "rtd/gentle/CarRide.h"
+#include "rtd/gentle/Circus.h"
+#include "rtd/gentle/CrookedHouse.h"
+#include "rtd/gentle/Dodgems.h"
+#include "rtd/gentle/FerrisWheel.h"
+#include "rtd/gentle/FlyingSaucers.h"
+#include "rtd/gentle/GhostTrain.h"
+#include "rtd/gentle/HauntedHouse.h"
+#include "rtd/gentle/Maze.h"
+#include "rtd/gentle/MerryGoRound.h"
+#include "rtd/gentle/MiniGolf.h"
+#include "rtd/gentle/MiniHelicopters.h"
+#include "rtd/gentle/MonorailCycles.h"
+#include "rtd/gentle/MonsterTrucks.h"
+#include "rtd/gentle/ObservationTower.h"
+#include "rtd/gentle/SpaceRings.h"
+#include "rtd/gentle/SpiralSlide.h"
+#include "rtd/shops/CashMachine.h"
+#include "rtd/shops/DrinkStall.h"
+#include "rtd/shops/FirstAid.h"
+#include "rtd/shops/FoodStall.h"
+#include "rtd/shops/InformationKiosk.h"
+#include "rtd/shops/Shop.h"
+#include "rtd/shops/Toilets.h"
+#include "rtd/thrill/3DCinema.h"
+#include "rtd/thrill/Enterprise.h"
+#include "rtd/thrill/GoKarts.h"
+#include "rtd/thrill/LaunchedFreefall.h"
+#include "rtd/thrill/MagicCarpet.h"
+#include "rtd/thrill/MotionSimulator.h"
+#include "rtd/thrill/RotoDrop.h"
+#include "rtd/thrill/SwingingInverterShip.h"
+#include "rtd/thrill/SwingingShip.h"
+#include "rtd/thrill/TopSpin.h"
+#include "rtd/thrill/Twist.h"
+#include "rtd/transport/Chairlift.h"
+#include "rtd/transport/Lift.h"
+#include "rtd/transport/MiniatureRailway.h"
+#include "rtd/transport/Monorail.h"
+#include "rtd/transport/SuspendedMonorail.h"
+#include "rtd/water/BoatHire.h"
+#include "rtd/water/DinghySlide.h"
+#include "rtd/water/LogFlume.h"
+#include "rtd/water/RiverRafts.h"
+#include "rtd/water/RiverRapids.h"
+#include "rtd/water/SplashBoats.h"
+#include "rtd/water/SubmarineRide.h"
 
 #include <iterator>
 
