@@ -9,7 +9,6 @@
 
 #pragma once
 
-#include "../common.h"
 #include "Track.h"
 
 constexpr uint8_t MaxSequencesPerPiece = 16;
@@ -62,11 +61,11 @@ struct DodgemsTrackSize
 
 constexpr DodgemsTrackSize GetDodgemsTrackSize(track_type_t type)
 {
-    if (type == TrackElemType::FlatTrack2x2)
+    if (type == OpenRCT2::TrackElemType::FlatTrack2x2)
         return { 4, 4, 59, 59 };
-    if (type == TrackElemType::FlatTrack4x4)
+    if (type == OpenRCT2::TrackElemType::FlatTrack4x4)
         return { 4, 4, 123, 123 };
-    if (type == TrackElemType::FlatTrack2x4)
+    if (type == OpenRCT2::TrackElemType::FlatTrack2x4)
         return { 4, 4, 59, 123 };
     return { 0, 0, 0, 0 };
 }
