@@ -9,7 +9,6 @@
 
 #pragma once
 
-#include "../common.h"
 #include "../paint/Paint.h"
 #include "../paint/support/MetalSupports.h"
 #include "../paint/tile_element/Paint.TileElement.h"
@@ -400,8 +399,6 @@ constexpr bool kDiagSpriteMap[kNumOrthogonalDirections][4] = {
 
 extern const uint8_t mapLeftEighthTurnToOrthogonal[5];
 
-extern const size_t MiniGolfPeepAnimationLengths[];
-
 ImageId GetStationColourScheme(PaintSession& session, const TrackElement& trackElement);
 ImageId GetShopSupportColourScheme(PaintSession& session, const TrackElement& trackElement);
 
@@ -603,15 +600,15 @@ TRACK_PAINT_FUNCTION GetTrackPaintFunctionInvertedImpulseRC(int32_t trackType);
 TRACK_PAINT_FUNCTION GetTrackPaintFunctionMiniRC(int32_t trackType);
 TRACK_PAINT_FUNCTION GetTrackPaintFunctionMineRide(int32_t trackType);
 TRACK_PAINT_FUNCTION GetTrackPaintFunctionLimLaunchedRC(int32_t trackType);
-namespace HybridRC
+namespace OpenRCT2::HybridRC
 {
     TRACK_PAINT_FUNCTION GetTrackPaintFunction(int32_t trackType);
 }
-namespace SingleRailRC
+namespace OpenRCT2::SingleRailRC
 {
     TRACK_PAINT_FUNCTION GetTrackPaintFunction(int32_t trackType);
 }
-namespace AlpineRC
+namespace OpenRCT2::AlpineRC
 {
     TRACK_PAINT_FUNCTION GetTrackPaintFunction(int32_t trackType);
 }
