@@ -13,7 +13,7 @@
 
 #include <cstdint>
 
-constexpr const size_t VehicleTrackSubpositionSizeDefault = TrackElemType::Count * kNumOrthogonalDirections;
+constexpr const size_t VehicleTrackSubpositionSizeDefault = OpenRCT2::TrackElemType::Count * kNumOrthogonalDirections;
 
 struct VehicleInfo;
 
