@@ -10,11 +10,11 @@
 #include "TitleScene.h"
 
 #include "../../Context.h"
+#include "../../Diagnostic.h"
 #include "../../Game.h"
 #include "../../GameState.h"
 #include "../../Input.h"
 #include "../../OpenRCT2.h"
-#include "../../Version.h"
 #include "../../audio/audio.h"
 #include "../../config/Config.h"
 #include "../../core/Console.hpp"
@@ -22,7 +22,6 @@
 #include "../../interface/Screenshot.h"
 #include "../../interface/Viewport.h"
 #include "../../interface/Window.h"
-#include "../../localisation/Localisation.h"
 #include "../../network/NetworkBase.h"
 #include "../../network/network.h"
 #include "../../scenario/Scenario.h"
@@ -91,16 +90,6 @@ bool TitleScene::IsPreviewingSequence()
     return _previewingSequence;
 }
 
-bool TitleScene::ShouldHideVersionInfo()
-{
-    return _hideVersionInfo;
-}
-
-void TitleScene::SetHideVersionInfo(bool value)
-{
-    _hideVersionInfo = value;
-}
-
 void TitleScene::Load()
 {
     LOG_VERBOSE("TitleScene::Load()");
@@ -120,18 +109,8 @@ void TitleScene::Load()
     gameStateInitAll(GetGameState(), DEFAULT_MAP_SIZE);
     ViewportInitAll();
     ContextOpenWindow(WindowClass::MainWindow);
-    CreateWindows();
-
-    GetContext().OpenProgress(STR_LOADING_TITLE_SEQUENCE);
 
     TitleInitialise();
-    OpenRCT2::Audio::PlayTitleMusic();
-
-    if (gOpenRCT2ShowChangelog)
-    {
-        gOpenRCT2ShowChangelog = false;
-        ContextOpenWindow(WindowClass::Changelog);
-    }
 
     if (_sequencePlayer != nullptr)
     {
@@ -142,7 +121,15 @@ void TitleScene::Load()
         _sequencePlayer->Update();
     }
 
-    GetContext().CloseProgress();
+    Audio::PlayTitleMusic();
+
+    CreateWindows();
+
+    if (gOpenRCT2ShowChangelog)
+    {
+        gOpenRCT2ShowChangelog = false;
+        ContextOpenWindow(WindowClass::Changelog);
+    }
 
     LOG_VERBOSE("TitleScene::Load() finished");
 }
@@ -192,7 +179,7 @@ void TitleScene::ChangePresetSequence(size_t preset)
         return;
     }
 
-    const utf8* configId = TitleSequenceManagerGetConfigID(preset);
+    const utf8* configId = TitleSequenceManager::GetConfigID(preset);
     Config::Get().interface.CurrentTitleSequencePreset = configId;
 
     if (!_previewingSequence)
@@ -210,8 +197,8 @@ void TitleScene::CreateWindows()
     ContextOpenWindow(WindowClass::TitleExit);
     ContextOpenWindow(WindowClass::TitleOptions);
     ContextOpenWindow(WindowClass::TitleLogo);
+    ContextOpenWindow(WindowClass::TitleVersion);
     WindowResizeGui(ContextGetWidth(), ContextGetHeight());
-    _hideVersionInfo = false;
 }
 
 void TitleScene::TitleInitialise()
@@ -261,7 +248,7 @@ void TitleScene::TitleInitialise()
             while (!safeSequence)
             {
                 random = UtilRand() % static_cast<int32_t>(total);
-                const utf8* scName = TitleSequenceManagerGetName(random);
+                const utf8* scName = TitleSequenceManager::GetName(random);
                 if (scName == RCT1String)
                 {
                     safeSequence = RCT1Installed;
@@ -285,7 +272,7 @@ void TitleScene::TitleInitialise()
     size_t seqId = TitleGetConfigSequence();
     if (seqId == SIZE_MAX)
     {
-        seqId = TitleSequenceManagerGetIndexForConfigID("*OPENRCT2");
+        seqId = TitleSequenceManager::GetIndexForConfigID("*OPENRCT2");
         if (seqId == SIZE_MAX)
         {
             seqId = 0;
@@ -315,7 +302,7 @@ bool TitleScene::TryLoadSequence(bool loadPreview)
                     if (targetSequence != _currentSequence && !loadPreview)
                     {
                         // Forcefully change the preset to a preset that works.
-                        const utf8* configId = TitleSequenceManagerGetConfigID(targetSequence);
+                        const utf8* configId = TitleSequenceManager::GetConfigID(targetSequence);
                         Config::Get().interface.CurrentTitleSequencePreset = configId;
                     }
                     _currentSequence = targetSequence;
@@ -370,30 +357,9 @@ void TitleSequenceChangePreset(size_t preset)
     }
 }
 
-bool TitleShouldHideVersionInfo()
-{
-    auto* context = OpenRCT2::GetContext();
-    auto* titleScene = static_cast<TitleScene*>(context->GetTitleScene());
-    if (titleScene != nullptr)
-    {
-        return titleScene->ShouldHideVersionInfo();
-    }
-    return false;
-}
-
-void TitleSetHideVersionInfo(bool value)
-{
-    auto* context = OpenRCT2::GetContext();
-    auto* titleScene = static_cast<TitleScene*>(context->GetTitleScene());
-    if (titleScene != nullptr)
-    {
-        titleScene->SetHideVersionInfo(value);
-    }
-}
-
 size_t TitleGetConfigSequence()
 {
-    return TitleSequenceManagerGetIndexForConfigID(Config::Get().interface.CurrentTitleSequencePreset.c_str());
+    return TitleSequenceManager::GetIndexForConfigID(Config::Get().interface.CurrentTitleSequencePreset.c_str());
 }
 
 size_t TitleGetCurrentSequence()
@@ -438,30 +404,3 @@ bool TitleIsPreviewingSequence()
     }
     return false;
 }
-
-void DrawOpenRCT2(DrawPixelInfo& dpi, const ScreenCoordsXY& screenCoords)
-{
-    thread_local std::string buffer;
-    buffer.clear();
-    buffer.assign("{OUTLINE}{WHITE}");
-
-    // Write name and version information
-    buffer += gVersionInfoFull;
-
-    DrawText(dpi, screenCoords + ScreenCoordsXY(5, 5 - 13), { COLOUR_BLACK }, buffer.c_str());
-    int16_t width = static_cast<int16_t>(GfxGetStringWidth(buffer, FontStyle::Medium));
-
-    // Write platform information
-    buffer.assign("{OUTLINE}{WHITE}");
-    buffer.append(OPENRCT2_PLATFORM);
-    buffer.append(" (");
-    buffer.append(OPENRCT2_ARCHITECTURE);
-    buffer.append(")");
-
-    DrawText(dpi, screenCoords + ScreenCoordsXY(5, 5), { COLOUR_BLACK }, buffer.c_str());
-    width = std::max(width, static_cast<int16_t>(GfxGetStringWidth(buffer, FontStyle::Medium)));
-
-    // Invalidate screen area
-    GfxSetDirtyBlocks({ screenCoords - ScreenCoordsXY(0, 13),
-                        screenCoords + ScreenCoordsXY{ width + 5, 30 } }); // 30 is an arbitrary height to catch both strings
-}
