@@ -12,7 +12,6 @@
 #ifdef ENABLE_SCRIPTING
 
 #    include "../actions/CustomAction.h"
-#    include "../common.h"
 #    include "../core/FileWatcher.h"
 #    include "../management/Finance.h"
 #    include "../world/Location.hpp"
@@ -33,7 +32,7 @@ struct duk_hthread;
 typedef struct duk_hthread duk_context;
 
 class GameAction;
-namespace GameActions
+namespace OpenRCT2::GameActions
 {
     class Result;
 }
@@ -47,7 +46,7 @@ namespace OpenRCT2
 
 namespace OpenRCT2::Scripting
 {
-    static constexpr int32_t OPENRCT2_PLUGIN_API_VERSION = 94;
+    static constexpr int32_t OPENRCT2_PLUGIN_API_VERSION = 97;
 
     // Versions marking breaking changes.
     static constexpr int32_t API_VERSION_33_PEEP_DEPRECATION = 33;
