@@ -12,7 +12,6 @@
 #    include "ScMap.hpp"
 
 #    include "../../../GameState.h"
-#    include "../../../common.h"
 #    include "../../../entity/Balloon.h"
 #    include "../../../entity/Duck.h"
 #    include "../../../entity/EntityList.h"
@@ -159,7 +158,29 @@ namespace OpenRCT2::Scripting
         {
             for (auto sprite : EntityList<Staff>())
             {
-                result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScStaff>(sprite->Id)));
+                auto staff = GetEntity<Staff>(sprite->Id);
+                if (staff != nullptr)
+                {
+                    switch (staff->AssignedStaffType)
+                    {
+                        case StaffType::Handyman:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScHandyman>(sprite->Id)));
+                            break;
+                        case StaffType::Mechanic:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScMechanic>(sprite->Id)));
+                            break;
+                        case StaffType::Security:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScSecurity>(sprite->Id)));
+                            break;
+                        default:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScStaff>(sprite->Id)));
+                            break;
+                    }
+                }
+                else
+                {
+                    result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScStaff>(sprite->Id)));
+                }
             }
         }
         else if (type == "crashed_vehicle_particle")
@@ -226,7 +247,29 @@ namespace OpenRCT2::Scripting
         {
             for (auto sprite : EntityTileList<Staff>(pos))
             {
-                result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScStaff>(sprite->Id)));
+                auto staff = GetEntity<Staff>(sprite->Id);
+                if (staff != nullptr)
+                {
+                    switch (staff->AssignedStaffType)
+                    {
+                        case StaffType::Handyman:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScHandyman>(sprite->Id)));
+                            break;
+                        case StaffType::Mechanic:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScMechanic>(sprite->Id)));
+                            break;
+                        case StaffType::Security:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScSecurity>(sprite->Id)));
+                            break;
+                        default:
+                            result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScStaff>(sprite->Id)));
+                            break;
+                    }
+                }
+                else
+                {
+                    result.push_back(GetObjectAsDukValue(_context, std::make_shared<ScStaff>(sprite->Id)));
+                }
             }
         }
         else if (type == "crashed_vehicle_particle")
@@ -358,7 +401,27 @@ namespace OpenRCT2::Scripting
             case EntityType::Vehicle:
                 return GetObjectAsDukValue(_context, std::make_shared<ScVehicle>(spriteId));
             case EntityType::Staff:
-                return GetObjectAsDukValue(_context, std::make_shared<ScStaff>(spriteId));
+            {
+                auto staff = GetEntity<Staff>(spriteId);
+                if (staff != nullptr)
+                {
+                    switch (staff->AssignedStaffType)
+                    {
+                        case StaffType::Handyman:
+                            return GetObjectAsDukValue(_context, std::make_shared<ScHandyman>(spriteId));
+                        case StaffType::Mechanic:
+                            return GetObjectAsDukValue(_context, std::make_shared<ScMechanic>(spriteId));
+                        case StaffType::Security:
+                            return GetObjectAsDukValue(_context, std::make_shared<ScSecurity>(spriteId));
+                        default:
+                            return GetObjectAsDukValue(_context, std::make_shared<ScStaff>(spriteId));
+                    }
+                }
+                else
+                {
+                    return GetObjectAsDukValue(_context, std::make_shared<ScStaff>(spriteId));
+                }
+            }
             case EntityType::Guest:
                 return GetObjectAsDukValue(_context, std::make_shared<ScGuest>(spriteId));
             case EntityType::Litter:
