@@ -14,9 +14,12 @@
 #include "../scenario/Scenario.h"
 #include "Util.h"
 
+#include <cassert>
 #include <cstring>
 #include <stdexcept>
 
+using namespace OpenRCT2;
+
 static size_t DecodeChunkRLE(const uint8_t* src_buffer, uint8_t* dst_buffer, size_t length);
 static size_t DecodeChunkRLEWithSize(const uint8_t* src_buffer, uint8_t* dst_buffer, size_t length, size_t dstSize);
 
