@@ -18,7 +18,6 @@
 #include "../entity/Staff.h"
 #include "../interface/Viewport.h"
 #include "../network/network.h"
-#include "../paint/VirtualFloor.h"
 #include "../ride/RideConstruction.h"
 #include "../ride/RideData.h"
 #include "../ride/Track.h"
@@ -33,6 +32,7 @@
 
 using namespace OpenRCT2;
 using namespace OpenRCT2::TrackMetaData;
+
 bool gDisableErrorWindowSound = false;
 
 RideConstructionState _rideConstructionState2;
@@ -66,15 +66,6 @@ money64 PlaceProvisionalTrackPiece(
         if (_currentTrackPitchEnd != TrackPitch::None)
             ViewportSetVisibility(ViewportVisibility::TrackHeights);
 
-        // Invalidate previous track piece (we may not be changing height!)
-        VirtualFloorInvalidate();
-
-        if (!SceneryToolIsActive())
-        {
-            // Set new virtual floor height.
-            VirtualFloorSetHeight(trackPos.z);
-        }
-
         return result.Cost;
     }
 
@@ -87,17 +78,12 @@ money64 PlaceProvisionalTrackPiece(
     if (res.Error != GameActions::Status::Ok)
         return kMoney64Undefined;
 
-    int16_t z_begin, z_end;
+    int16_t z_begin{};
     const auto& ted = GetTrackElementDescriptor(trackType);
     const TrackCoordinates& coords = ted.Coordinates;
     if (ride->GetRideTypeDescriptor().HasFlag(RIDE_TYPE_FLAG_HAS_TRACK))
     {
         z_begin = coords.z_begin;
-        z_end = coords.z_end;
-    }
-    else
-    {
-        z_end = z_begin = coords.z_begin;
     }
 
     _unkF440C5 = { trackPos.x, trackPos.y, trackPos.z + z_begin, static_cast<Direction>(trackDirection) };
@@ -110,15 +96,6 @@ money64 PlaceProvisionalTrackPiece(
     if (_currentTrackPitchEnd != TrackPitch::None)
         ViewportSetVisibility(ViewportVisibility::TrackHeights);
 
-    // Invalidate previous track piece (we may not be changing height!)
-    VirtualFloorInvalidate();
-
-    if (!SceneryToolIsActive())
-    {
-        // Set height to where the next track piece would begin
-        VirtualFloorSetHeight(trackPos.z - z_begin + z_end);
-    }
-
     return res.Cost;
 }
 
@@ -395,16 +372,6 @@ bool WindowRideConstructionUpdateState(
     return false;
 }
 
-/**
- *
- *  rct2: 0x006C84CE
- */
-void WindowRideConstructionUpdateActiveElements()
-{
-    auto intent = Intent(INTENT_ACTION_RIDE_CONSTRUCTION_UPDATE_ACTIVE_ELEMENTS);
-    ContextBroadcastIntent(&intent);
-}
-
 /**
  *
  *  rct2: 0x0066DB3D
@@ -414,20 +381,10 @@ bool SceneryToolIsActive()
     auto toolWindowClassification = gCurrentToolWidget.window_classification;
     WidgetIndex toolWidgetIndex = gCurrentToolWidget.widget_index;
     if (InputTestFlag(INPUT_FLAG_TOOL_ACTIVE))
-        if (toolWindowClassification == WindowClass::TopToolbar && toolWidgetIndex == WC_TOP_TOOLBAR__WIDX_SCENERY)
+    {
+        if (toolWindowClassification == WindowClass::Scenery && toolWidgetIndex == WC_SCENERY__WIDX_SCENERY_BACKGROUND)
             return true;
+    }
 
     return false;
 }
-
-void SceneryInit()
-{
-    auto intent = Intent(INTENT_ACTION_INIT_SCENERY);
-    ContextBroadcastIntent(&intent);
-}
-
-void ScenerySetDefaultPlacementConfiguration()
-{
-    auto intent = Intent(INTENT_ACTION_SET_DEFAULT_SCENERY_CONFIG);
-    ContextBroadcastIntent(&intent);
-}
