@@ -31,8 +31,6 @@
 #include "MapAnimation.h"
 #include "Park.h"
 
-#include <algorithm>
-
 using namespace OpenRCT2;
 
 bool gParkEntranceGhostExists = false;
@@ -70,7 +68,7 @@ void ParkEntranceRemoveGhost()
 int32_t ParkEntranceGetIndex(const CoordsXYZ& entrancePos)
 {
     int32_t i = 0;
-    for (const auto& entrance : GetGameState().ParkEntrances)
+    for (const auto& entrance : GetGameState().Park.Entrances)
     {
         if (entrancePos == entrance)
         {
@@ -83,7 +81,7 @@ int32_t ParkEntranceGetIndex(const CoordsXYZ& entrancePos)
 
 void ParkEntranceReset()
 {
-    GetGameState().ParkEntrances.clear();
+    GetGameState().Park.Entrances.clear();
 }
 
 void RideEntranceExitPlaceProvisionalGhost()
@@ -214,17 +212,17 @@ void ParkEntranceFixLocations(void)
 {
     auto& gameState = GetGameState();
     // Fix ParkEntrance locations for which the tile_element no longer exists
-    gameState.ParkEntrances.erase(
+    gameState.Park.Entrances.erase(
         std::remove_if(
-            gameState.ParkEntrances.begin(), gameState.ParkEntrances.end(),
+            gameState.Park.Entrances.begin(), gameState.Park.Entrances.end(),
             [](const auto& entrance) { return MapGetParkEntranceElementAt(entrance, false) == nullptr; }),
-        gameState.ParkEntrances.end());
+        gameState.Park.Entrances.end());
 }
 
 void ParkEntranceUpdateLocations()
 {
     auto& gameState = GetGameState();
-    gameState.ParkEntrances.clear();
+    gameState.Park.Entrances.clear();
     TileElementIterator it;
     TileElementIteratorBegin(&it);
     while (TileElementIteratorNext(&it))
@@ -234,7 +232,7 @@ void ParkEntranceUpdateLocations()
             && entranceElement->GetSequenceIndex() == 0 && !entranceElement->IsGhost())
         {
             auto entrance = TileCoordsXYZD(it.x, it.y, it.element->BaseHeight, it.element->GetDirection()).ToCoordsXYZD();
-            gameState.ParkEntrances.push_back(entrance);
+            gameState.Park.Entrances.push_back(entrance);
         }
     }
 }
