@@ -10,7 +10,6 @@
 #pragma once
 
 #include "../Identifiers.h"
-#include "../common.h"
 #include "Location.hpp"
 #include "Map.h"
 
@@ -21,21 +20,21 @@ enum
     ENTRANCE_ELEMENT_FLAGS2_LEGACY_PATH_ENTRY = (1 << 0),
 };
 
-namespace EntranceSequence
+namespace OpenRCT2::EntranceSequence
 {
     constexpr uint8_t Centre = 0;
     constexpr uint8_t Left = 1;
     constexpr uint8_t Right = 2;
-}; // namespace EntranceSequence
+}; // namespace OpenRCT2::EntranceSequence
 
-constexpr const uint8_t ParkEntranceHeight = 12 * COORDS_Z_STEP;
-constexpr const uint8_t RideEntranceHeight = 7 * COORDS_Z_STEP;
-constexpr const uint8_t RideExitHeight = 5 * COORDS_Z_STEP;
+constexpr uint8_t ParkEntranceHeight = 12 * kCoordsZStep;
+constexpr uint8_t RideEntranceHeight = 7 * kCoordsZStep;
+constexpr uint8_t RideExitHeight = 5 * kCoordsZStep;
 
 extern bool gParkEntranceGhostExists;
 extern CoordsXYZD gParkEntranceGhostPosition;
 
-constexpr int32_t MaxRideEntranceOrExitHeight = 244 * COORDS_Z_STEP;
+constexpr int32_t MaxRideEntranceOrExitHeight = 244 * kCoordsZStep;
 
 extern CoordsXYZD gRideEntranceExitGhostPosition;
 extern StationIndex gRideEntranceExitGhostStationIndex;
