@@ -10,14 +10,13 @@
 #pragma once
 
 #include "../Identifiers.h"
-#include "../common.h"
-#include "../interface/Viewport.h"
 #include "../object/Object.h"
 
 class FootpathObject;
 class FootpathSurfaceObject;
 class FootpathRailingsObject;
 struct PathElement;
+struct TileElement;
 
 enum
 {
@@ -26,10 +25,10 @@ enum
     PROVISIONAL_PATH_FLAG_2 = (1 << 2),
 };
 
-constexpr auto FootpathMaxHeight = 248 * COORDS_Z_STEP;
-constexpr auto FootpathMinHeight = 2 * COORDS_Z_STEP;
-constexpr auto PATH_HEIGHT_STEP = 2 * COORDS_Z_STEP;
-constexpr auto PATH_CLEARANCE = 4 * COORDS_Z_STEP;
+constexpr auto FootpathMaxHeight = 248 * kCoordsZStep;
+constexpr auto FootpathMinHeight = 2 * kCoordsZStep;
+constexpr auto PATH_HEIGHT_STEP = 2 * kCoordsZStep;
+constexpr auto PATH_CLEARANCE = 4 * kCoordsZStep;
 
 enum class RailingEntrySupportType : uint8_t
 {
@@ -59,11 +58,11 @@ struct PathRailingsDescriptor
 };
 
 using PathConstructFlags = uint8_t;
-namespace PathConstructFlag
+namespace OpenRCT2::PathConstructFlag
 {
     constexpr PathConstructFlags IsQueue = 1 << 0;
     constexpr PathConstructFlags IsLegacyPathObject = 1 << 1;
-} // namespace PathConstructFlag
+} // namespace OpenRCT2::PathConstructFlag
 
 struct FootpathSelection
 {
@@ -192,8 +191,6 @@ money64 FootpathProvisionalSet(
     PathConstructFlags constructFlags);
 void FootpathProvisionalRemove();
 void FootpathProvisionalUpdate();
-CoordsXY FootpathGetCoordinatesFromPos(const ScreenCoordsXY& screenCoords, int32_t* direction, TileElement** tileElement);
-CoordsXY FootpathBridgeGetInfoFromPos(const ScreenCoordsXY& screenCoords, int32_t* direction, TileElement** tileElement);
 void FootpathRemoveLitter(const CoordsXYZ& footpathPos);
 void FootpathConnectEdges(const CoordsXY& footpathPos, TileElement* tileElement, int32_t flags);
 void FootpathUpdateQueueChains();
