@@ -48,8 +48,8 @@ protected:
     {
         RatingTuple ratings = ride.ratings;
         std::string line = String::StdFormat(
-            "%s: (%d, %d, %d)", ride.GetRideTypeDescriptor().EnumName, static_cast<int>(ratings.Excitement),
-            static_cast<int>(ratings.Intensity), static_cast<int>(ratings.Nausea));
+            "%s: (%d, %d, %d)", ride.GetRideTypeDescriptor().EnumName, static_cast<int>(ratings.excitement),
+            static_cast<int>(ratings.intensity), static_cast<int>(ratings.nausea));
         return line;
     }
 
