@@ -17,7 +17,7 @@
 int main(int argc, char** argv)
 {
     // Abort on an assertions so the tests do not hang
-    Guard::SetAssertBehaviour(ASSERT_BEHAVIOUR::ABORT);
+    OpenRCT2::Guard::SetAssertBehaviour(ASSERT_BEHAVIOUR::ABORT);
 
     testing::InitGoogleTest(&argc, argv);
     return RUN_ALL_TESTS();
